LocalScaling — hubness 0.21a1 documentation

# LocalScaling

class `hubness.reduction.` `LocalScaling`(k: int = 5, method: str = 'standard', verbose: int = 0)

  Bases: `object`

  Hubness reduction with local scaling.

  Methods Summary

  `fit`(neigh_dist, neigh_ind[, assume_sorted]) |
  `transform`(neigh_dist, neigh_ind[, assume_sorted]) |

  Methods Documentation

  `fit`(neigh_dist, neigh_ind, assume_sorted: bool = True) → hubness.reduction.scaling.LocalScaling
  `transform`(neigh_dist, neigh_ind, assume_sorted: bool = True, *args, **kwargs) -> (np.ndarray, np.ndarray)